pub fn preview(width: usize, input: &StyledString) -> StyledStringExpand description
Preview markdown of the given length Currently removes any color (i.e. code highlighting) to avoid the jarring issue of a fragmented highlight style on focused items.